/********************************************************************
*	MLX16_T.H
*
*	This header files consists some types for the 
*	SORCUS libraries used on following platforms:
*
*	Operating System:		DOS
*								Windows 3.x
*
*	SORCUS Boards:			ML8 - MODULAR-4/486
*								ML6 - Multi-COM
*								ML2 - Multi-LAB/2
*								
*
*  Authors:					Dipl.-Ing. H.Doersam
*								Dipl-Ing. M.Haecker
*
*  Copyrights:				SORCUS Computer GmbH 1995 .. 1998
*								All Rights Reserved
********************************************************************/



#ifndef _INC_MLX16_T

#define _INC_MLX16_T



#ifndef _MLXTYPES_
#define _MLXTYPES_

   #define byte            unsigned char           /* 1 byte */
   #define M8BOOL          unsigned char           /* 1 byte */
   #define M2BOOL          unsigned char           /* 1 byte */
   #define ML2BOOL         unsigned char           /* 1 byte */
   #define ushort          unsigned short          /* 2 bytes */
   #define ulong           unsigned long           /* 4 bytes */
   #define HML2            unsigned short          /* 2 Byte, 
                                                      Handle fr MultiLAB/2 */

   typedef  unsigned long  HMDD8;               /* Handle fuer MDD (ML8) */
   typedef  unsigned long  HMDD6;               /* Handle fuer MDD (ML6) */
   typedef  unsigned long  HMDD2;               /* Handle fuer MDD (ML2) */

   #define VOID            void
   #define UCHAR           byte
   #define CHAR            char
   #define USHORT          ushort
   #define SHORT           short
   #define ULONG           ulong
   #define LONG            long

#endif // !_MLXTYPES_


/* This is the error record type that you can evaluate when an error
   occures.  See explanation in manual */
typedef struct ml8_error_info_type 
{
   M8BOOL       ok;
   M8BOOL       repeatmacro;
   byte         errorcode;
   byte         errorclass;
   byte         statusport;
   byte         statusmap;
		/* Bitmap: only set >0 if an error occured
			0 = error without ml8_clear_error (send macro)
			1 = error without ml8_clear_error (receive macro)
			2 = free
			3 = free
			4 = free
			5 = free
			6 = error request
			7 = library not initialized for board */
   ushort       errorrequest;
   ushort       sndcount;
   ushort       rcvcount;
   ushort       mark;
   char         markmsgsize[1];
   char         markmessage[80];
   ushort       outwords[MAX_ERR_OUT_CMD];       /* commands of macro (send) */
   ushort       inwords[MAX_ERR_IN_CMD];         /* commands of macro (receive) */
   ushort       datawords[MAX_ERR_OUT_DATA];     /* data of macro (send) */
   char         errormsgsize[1];
   char         errormessage[80];
   ushort       maxerrorretry;
   ushort       errorretry;
} ml8_error_info_typ;


// MICRO TIME CODE
typedef struct
{
	byte		ucRes;				//	Reserved
	byte		ucHours;				//	Hours (0..23)
	byte		ucMinutes;			//	Minutes (0..59)
	byte		ucSec;				//	Seconds (0..59)
	ushort	usMilliSec;			//	Milliseconds (0..999)
	ushort	usMicroSec;			//	Microseconds (0..999)
} MICRO_TIME_CODE;




/**** typedefs for error handler and srq handler ****/
#if defined (_Windows)
   /* procedures */
   typedef void PFAR _export ERROR_PROC (void);
   typedef void PFAR _export SERVICE_PROC (void);
   /* pointers to procedures */
   typedef void PFAR (PFAR _export *ERROR_PROC_P) (void);
   typedef void PFAR (PFAR _export *SERVICE_PROC_P) (void);
#else
   /* procedures */
   typedef void PFAR ERROR_PROC (void);
   typedef void PFAR SERVICE_PROC (void);
   /* pointers to procedures */
   typedef void (PFAR  *ERROR_PROC_P) (void);
   typedef void (PFAR  *SERVICE_PROC_P) (void);
#endif


#endif // !_INC_MLX16_T


